'use strict';

var React = require('react');
var YYClass = require('../../base/YYClass');
var PropTypes = YYClass.PropTypes;
var field = YYClass.field;
var formatUtils = require('../../../utils/formatUtils');
var YYInputCurrency = require('../inputnumber/YYInputCurrency');
//定义META
var uiMeta = {
    name: 'text',
    fields: [, field('value', undefined, PropTypes.any, false, 'value 值'), field('style', undefined, PropTypes.any, false, '组件的style样式'), field('addonAfter', undefined, PropTypes.node, false, '设置后缀'), field('fieldtype', 'string', PropTypes.string, false, '表格字段列数据类型标识：string-文本（默认）、date-日期、currency-精确数值'), field('decimal', 3, PropTypes.number, false, '表格字段列数据类型为currency-精确数值时生效，定义精确的小数位，默认显示数据原始小数位'), field('showDecimal', undefined, PropTypes.number, false, "配置显示的小数点位数(输入态时按实际保留的精度进行显示),仅当type = 'currency'时生效，未配置则按decimal属性值进行显示。"), field('comma', true, PropTypes.bool, false, '表格字段列数据类型为currency-精确数值时生效，定义是否格式化显示千分位'), field('zeroFilling', true, PropTypes.bool, false, '表格字段列数据类型为currency-精确数值时生效，定义是否自动补0'), field('format', undefined, PropTypes.string, false, '日期格式化yyyy-MM-dd|yyyy-MM-dd HH:mm:ss'), field('onRenderText', null, PropTypes.func, false, '自定义渲染文本显示视图')]
};
var YYText = YYClass.create({
    uiMeta: uiMeta,
    getInitialState: function getInitialState() {
        return {
            value: this.props.value
        };
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        if ("value" in nextProps) {
            this.setState({
                value: nextProps.value
            });
        }
    },
    render: function render() {
        var _props = this.props,
            value = _props.value,
            showDecimal = _props.showDecimal,
            comma = _props.comma,
            zeroFilling = _props.zeroFilling;

        var textValue = value;
        if (this.props.fieldtype == 'currency') {
            var numStrs = (value + "").split(".");
            var decimal = numStrs.length == 2 ? numStrs[1].length : 0; //保留原始小数位
            if (this.props.decimal >= 0) decimal = this.props.decimal; //保留列定义的小数位
            var textDecimal = isNaN(parseInt(showDecimal)) ? decimal : showDecimal;
            textValue = YYInputCurrency.formatCurrency(value, { decimal: textDecimal != undefined ? textDecimal : 3, comma: comma, zeroFilling: zeroFilling });
        } else if (this.props.fieldtype == 'date') {
            if (textValue) {
                var format = this.props.format || 'yyyy-MM-dd';
                textValue = formatUtils.formatDate(formatUtils.parseAntDate(textValue), format);
            }
        }
        var contenxt = textValue ? textValue : this.props.children;
        if (typeof this.props.onRenderText == 'function') {
            contenxt = this.props.onRenderText(contenxt);
        }
        return React.createElement(
            'div',
            { className: this.className(), style: this.props.style, title: value },
            contenxt,
            textValue ? this.props.addonAfter : null
        );
    }
});
module.exports = YYText;